;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "popwin" "20240925.752"
  "Popup Window Manager."
  '((emacs "24.3"))
  :url "https://github.com/emacsorphanage/popwin"
  :commit "58adcd0ca7c3dbd58626ec7019252d64cbc73042"
  :revdesc "58adcd0ca7c3"
  :keywords '("convenience")
  :authors '(("Tomohiro Matsuyama" . "m2ym.pub@gmail.com"))
  :maintainers '(("Jen-Chieh Shen" . "jcs090218@gmail.com")))
